@@ -26,6 +26,8 @@ def get_backend():
     except ImportError as e:
         raise ImproperlyConfigured(
             _("Can't retrieve the image backend '{}'. Message: '{}'.").format(
-                settings.IMAGE_CROPPING_BACKEND, e))
+                settings.IMAGE_CROPPING_BACKEND, e
+            )
+        )
 
     return cls(**settings.IMAGE_CROPPING_BACKEND_PARAMS)
